@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2011 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010 -- leonerd@leonerd.org.uk
 
 package Socket::GetAddrInfo::Socket6api;
 
@@ -10,10 +10,10 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.21_003';
+our $VERSION = '0.20';
 
 use Exporter 'import';
-our @EXPORT_OK = qw(
+our @EXPORT = qw(
    getaddrinfo
    getnameinfo
 );
@@ -21,8 +21,8 @@ our @EXPORT_OK = qw(
 use Socket::GetAddrInfo ();
 
 # Re-export all the AI_*, EAI_* and NI_* constants
-my @constants = @{ $Socket::GetAddrInfo::EXPORT_TAGS{constants} };
-push @EXPORT_OK, @constants;
+my @constants = grep m/^(E?A|N)I_/, @Socket::GetAddrInfo::EXPORT;
+push @EXPORT, @constants;
 Socket::GetAddrInfo->import( @constants );
 
 =head1 NAME
@@ -60,16 +60,21 @@ using L<Socket6> API
 
 =head1 DESCRIPTION
 
-L<Socket::GetAddrInfo> provides the functions of C<getaddrinfo> and
-C<getnameinfo> using a convenient interface where hints and address structures
-are represented as hashes. L<Socket6> also provides these functions, in a form
-taking and returning flat lists of values.
+L<Socket::GetAddrInfo> provides the RFC 2553-specified functions of
+C<getaddrinfo> and C<getnameinfo>, using a convenient interface where hints
+and address structures are represented as hashes. L<Socket6> also provides
+these functions, in a form taking and returning flat lists of values.
 
 This module wraps the functions provided by C<Socket::GetAddrInfo> to provide
 them in an identical API to C<Socket6>. It is intended to stand as a utility
 for existing code written for the C<Socket6> API to use these functions
 instead.
 
+These functions can also be obtained by importing from C<Socket::GetAddrInfo>
+using a special tag:
+
+ use Socket::GetAddrInfo qw( :Socket6api getaddrinfo );
+
 =cut
 
 =head1 FUNCTIONS
@@ -132,10 +137,11 @@ sub getnameinfo
    return ( $host, $service );
 }
 
+# Keep perl happy; keep Britain tidy
+1;
+
+__END__
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
-
-=cut
-
-0x55AA;
