@@ -8,13 +8,13 @@ package Socket::GetAddrInfo::XS;
 use strict;
 use warnings;
 
-our $VERSION = '0.21_003';
+our $VERSION = '0.20';
 
 # Load the actual code into Socket::GetAddrInfo
 package # hide from indexer
   Socket::GetAddrInfo;
 
-our @EXPORT_OK = qw(
+our @EXPORT = qw(
    getaddrinfo
    getnameinfo
 );
@@ -24,4 +24,5 @@ die '$Socket::GetAddrInfo::NO_XS is set' if our $NO_XS;
 require XSLoader;
 XSLoader::load( __PACKAGE__, $Socket::GetAddrInfo::XS::VERSION );
 
-0x55AA;
+# Keep perl happy; keep Britain tidy
+1;
